@@ -82,10 +82,10 @@ plot.keras_training_history <- function(x, y, metrics = NULL, method = c("auto",
       p <- ggplot2::ggplot(df, ggplot2::aes_(~epoch, ~value))
     
     if (smooth && x$params$epochs >= 10)
-      p <- p + ggplot2::geom_smooth(se = FALSE, method = 'loess')
+      p <- p + ggplot2::geom_smooth(se = FALSE, method = 'loess', na.rm = TRUE)
     
     p <- p +
-      ggplot2::geom_point(shape = 21, col = 1) +
+      ggplot2::geom_point(shape = 21, col = 1, na.rm = TRUE) +
       ggplot2::facet_grid(metric~., switch = 'y', scales = 'free_y') +
       ggplot2::scale_x_continuous(breaks = int_breaks) +
       ggplot2::theme(axis.title.y = ggplot2::element_blank(), strip.placement = 'outside',
@@ -137,16 +137,24 @@ plot.keras_training_history <- function(x, y, metrics = NULL, method = c("auto",
 
 #' @export
 as.data.frame.keras_training_history <- function(x, ...) {
+  # pad to epochs if necessary
+  values <- x$metrics
+  pad <- x$params$epochs - length(values$loss)
+  pad_data <- list()
+  for (metric in x$params$metrics)
+    pad_data[[metric]] <- rep_len(NA, pad)
+  values <- rbind(values, pad_data)
+
   # prepare data to plot as a data.frame
   df <- data.frame(
     epoch = seq_len(x$params$epochs),
-    value = unlist(x$metrics),
+    value = unlist(values),
     metric = rep(sub("^val_", "", names(x$metrics)), each = x$params$epochs),
     data = rep(grepl("^val_", names(x$metrics)), each = x$params$epochs)
   )
   rownames(df) <- NULL
   
-  # order factor levles appropriately
+  # order factor levels appropriately
   df$data <- factor(df$data, c(FALSE, TRUE), c('training', 'validation'))
   df$metric <- factor(df$metric, unique(sub("^val_", "", names(x$metrics))))
 
@@ -154,6 +162,26 @@ as.data.frame.keras_training_history <- function(x, ...) {
   df
 }
 
+to_keras_training_history <- function(history) {
+  
+  # turn history into an R object so it can be persited and
+  # and give it a class so we can write print/plot methods
+  params <- history$params
+  if (params$do_validation)
+    params$validation_samples <- dim(history$validation_data[[1]])[[1]]
+  
+  # normalize metrics
+  metrics <- history$history
+  metrics <- lapply(metrics, function(metric) {
+    as.numeric(lapply(metric, mean))
+  })
+  
+  # create history
+  keras_training_history(
+    params = params,
+    metrics = metrics
+  )
+}
 
 keras_training_history <- function(params, metrics) {
   
